
{ ----------------------------------------------------------------------------
                                 OS FLICKER EDIT
  ----------------------------------------------------------------------------

    Author: Oktay Sancak (ceoworks) - oktaysancak@yahoo.co.uk

    History
       28.11.2004 [05:44] TOSFlickerEdit v1.0
       
  ---------------------------------------------------------------------------- }

unit OsFlickerEdit;

interface

uses
  SysUtils, Classes, StdCtrls, ExtCtrls, Graphics;

type
  TOSFlickerEdit = class(TEdit)
  private
    FFlickTimer: TTimer;
    FFlickColor: TColor;
    FMainColor: TColor;
    procedure DoFlick(Sender: TObject);
    function GetFlickEnabled: Boolean;
    procedure SetFlickEnabled(const Value: Boolean);
    function GetFlickInterval: Cardinal;
    procedure SetFlickInterval(const Value: Cardinal);
  public
    constructor Create(AOwner: TComponent); override;
    destructor Destroy; override;
  published
    property FlickEnabled: Boolean read GetFlickEnabled write SetFlickEnabled;
    property FlickColor: TColor read FFlickColor write FFlickColor;
    property FlickInterval: Cardinal read GetFlickInterval write SetFlickInterval;
  end;

  procedure Register;

implementation

uses
  Dialogs;

procedure Register;
begin
  RegisterComponents('OS Controls', [TOSFlickerEdit]);
end;

{ TOSFlickerEdit }

constructor TOSFlickerEdit.Create(AOwner: TComponent);
begin
  inherited;
  FMainColor := Self.Color;
  FFlickColor := clYellow;

  FFlickTimer := TTimer.Create(Self);
  with FFlickTimer do
  begin
    OnTimer := DoFlick;
    Enabled := False;
  end;
end;

destructor TOSFlickerEdit.Destroy;
begin

  inherited;
end;

procedure TOSFlickerEdit.DoFlick(Sender: TObject);
begin
  if not (csDesigning in Self.ComponentState) then
  begin
    if (Self.Color = FFlickColor) then
      Self.Color := FMainColor
    else
      Self.Color := FFlickColor;
  end;
end;

function TOSFlickerEdit.GetFlickEnabled: Boolean;
begin
  Result := FFlickTimer.Enabled;
end;

function TOSFlickerEdit.GetFlickInterval: Cardinal;
begin
  Result := FFlickTimer.Interval;
end;

procedure TOSFlickerEdit.SetFlickEnabled(const Value: Boolean);
begin
  if (Value <> FFlickTimer.Enabled) then
  begin
    if (Value = True) then
      FMainColor := Self.Color
    else
      Self.Color := FMainColor;

    FFlickTimer.Enabled := Value;
  end;
end;

procedure TOSFlickerEdit.SetFlickInterval(const Value: Cardinal);
begin
  FFlickTimer.Interval := Value;
end;

end.
